plone.app.event.recurrence — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »

# plone.app.event.recurrence

class `plone.app.event.recurrence.` `EventOccurrenceAccessor`(context)

  Generic event accessor adapter implementation for Occurrence objects.

class `plone.app.event.recurrence.` `ImageScalingViewFactory`(context, request)

  Factory for ImageScaling view for occurrences. Delegates to AT or DX specific view and rebinds to the parent context.

class `plone.app.event.recurrence.` `Occurrence`(id, start, end)

  Mix-in class combining the most common set of basic mix-ins

class `plone.app.event.recurrence.` `OccurrenceTraverser`(context, request)

  Generic Occurrence traverser.

  Please note: the .at and .dx subpackages implement their own Occurrence traversers.

class `plone.app.event.recurrence.` `RecurrenceSupport`(context)

  IRecurrenceSupport Adapter.

  `occurrences`(range_start=None, range_end=None)

    Return all occurrences of an event, possibly within a start and end limit.

    Please note: Events beginning before range_start but ending afterwards
      won’t be found.

    TODO: test with event start = 21st feb, event end = start+36h, recurring for 10 days, range_start = 1st mar, range_end = last Mark

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »